# ontoim-py

[![Maintenance](https://img.shields.io/badge/Maintained%3F-yes-green.svg)](https://github.com/luca-martinelli-09/ontoim-py/graphs/commit-activity)
[![PyPI version](https://img.shields.io/pypi/v/ontoim-py.svg)](https://pypi.python.org/pypi/ontoim-py/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/ontoim-py.svg)](https://pypi.python.org/pypi/ontoim-py/)
[![PyPI status](https://img.shields.io/pypi/status/ontoim-py.svg)](https://pypi.python.org/pypi/ontoim-py/)

This python package helps in create and implements an [ontoim](https://github.com/luca-martinelli-09/ontoim) RDF.

# How it works

Same as [ontopia_py](https://github.com/luca-martinelli-09/ontopia-py)